@@ -4,10 +4,6 @@ from typing import Any, List, Optional, Type, TypeVar, Union, get_args, get_orig
 from attrs import define
 
 
-def is_optional(field) -> bool:
-    return get_origin(field) is Union and type(None) in get_args(field)
-
-
 class UnsetType:
     __instance: Optional["UnsetType"] = None
 
